@@ -2,13 +2,14 @@
 
 import itertools
 from collections import UserDict
-from typing import Any, Callable, Dict, List, MutableMapping, Union
+from typing import Any, Callable, Dict, List, Mapping, MutableMapping, Union
 
-from tabulator import Stream
+from hdx.utilities.frictionless_wrapper import get_frictionless_resource
+from hdx.utilities.typehint import ListDict, ListTuple
 
 
 def merge_two_dictionaries(
-    a: MutableMapping, b: MutableMapping, merge_lists: bool = False
+    a: MutableMapping, b: Mapping, merge_lists: bool = False
 ) -> MutableMapping:
     """Merges b into a and returns merged result
 
@@ -16,7 +17,7 @@ def merge_two_dictionaries(
 
     Args:
         a (MutableMapping): dictionary to merge into
-        b (MutableMapping): dictionary to merge from
+        b (Mapping): dictionary to merge from
         merge_lists (bool): Whether to merge lists (True) or replace lists (False). Default is False.
 
     Returns:
@@ -65,7 +66,7 @@ def merge_two_dictionaries(
 
 
 def merge_dictionaries(
-    dicts: List[MutableMapping], merge_lists: bool = False
+    dicts: ListTuple[MutableMapping], merge_lists: bool = False
 ) -> MutableMapping:
     """Merges all dictionaries in dicts into a single dictionary and returns result
 
@@ -83,14 +84,12 @@ def merge_dictionaries(
     return dict1
 
 
-def dict_diff(
-    d1: MutableMapping, d2: MutableMapping, no_key: str = "<KEYNOTFOUND>"
-) -> Dict:
+def dict_diff(d1: Mapping, d2: Mapping, no_key: str = "<KEYNOTFOUND>") -> Dict:
     """Compares two dictionaries
 
     Args:
-        d1 (MutableMapping): First dictionary to compare
-        d2 (MutableMapping): Second dictionary to compare
+        d1 (Mapping): First dictionary to compare
+        d2 (Mapping): Second dictionary to compare
         no_key (str): What value to use if key is not found Defaults to '<KEYNOTFOUND>'.
 
     Returns:
@@ -245,12 +244,12 @@ def list_distribute_contents(
 
 
 def extract_list_from_list_of_dict(
-    list_of_dict: List[MutableMapping], key: Any
+    list_of_dict: List[Mapping], key: Any
 ) -> List:
     """Extract a list by looking up key in each member of a list of dictionaries
 
     Args:
-        list_of_dict (List[MutableMapping]): List of dictionaries
+        list_of_dict (List[Mapping]): List of dictionaries
         key (Any): Key to find in each dictionary
 
     Returns:
@@ -264,7 +263,7 @@ def extract_list_from_list_of_dict(
 
 
 def key_value_convert(
-    dictin: MutableMapping,
+    dictin: Mapping,
     keyfn: Callable[[Any], Any] = lambda x: x,
     valuefn: Callable[[Any], Any] = lambda x: x,
     dropfailedkeys: bool = False,
@@ -274,7 +273,7 @@ def key_value_convert(
     """Convert keys and/or values of dictionary using functions passed in as parameters
 
     Args:
-        dictin (MutableMapping): Input dictionary
+        dictin (Mapping): Input dictionary
         keyfn (Callable[[Any], Any]): Function to convert keys. Defaults to lambda x: x
         valuefn (Callable[[Any], Any]): Function to convert values. Defaults to lambda x: x
         dropfailedkeys (bool): Whether to drop dictionary entries where key conversion fails. Defaults to False.
@@ -282,7 +281,7 @@ def key_value_convert(
         exception (Exception): The exception to expect if keyfn or valuefn fail. Defaults to ValueError.
 
     Returns:
-        Dict: Dictionary with converted keys and/or values
+        Dict: New dictionary with converted keys and/or values
 
     """
     dictout = dict()
@@ -304,13 +303,11 @@ def key_value_convert(
     return dictout
 
 
-def integer_key_convert(
-    dictin: MutableMapping, dropfailedkeys: bool = False
-) -> Dict:
+def integer_key_convert(dictin: Mapping, dropfailedkeys: bool = False) -> Dict:
     """Convert keys of dictionary to integers
 
     Args:
-        dictin (MutableMapping): Input dictionary
+        dictin (Mapping): Input dictionary
         dropfailedkeys (bool): Whether to drop dictionary entries where key conversion fails. Defaults to False.
 
     Returns:
@@ -321,12 +318,12 @@ def integer_key_convert(
 
 
 def integer_value_convert(
-    dictin: MutableMapping, dropfailedvalues: bool = False
+    dictin: Mapping, dropfailedvalues: bool = False
 ) -> Dict:
     """Convert values of dictionary to integers
 
     Args:
-        dictin (MutableMapping): Input dictionary
+        dictin (Mapping): Input dictionary
         dropfailedvalues (bool): Whether to drop dictionary entries where key conversion fails. Defaults to False.
 
     Returns:
@@ -339,12 +336,12 @@ def integer_value_convert(
 
 
 def float_value_convert(
-    dictin: MutableMapping, dropfailedvalues: bool = False
+    dictin: Mapping, dropfailedvalues: bool = False
 ) -> Dict:
     """Convert values of dictionary to floats
 
     Args:
-        dictin (MutableMapping): Input dictionary
+        dictin (Mapping): Input dictionary
         dropfailedvalues (bool): Whether to drop dictionary entries where key conversion fails. Defaults to False.
 
     Returns:
@@ -357,13 +354,13 @@ def float_value_convert(
 
 
 def avg_dicts(
-    dictin1: MutableMapping, dictin2: MutableMapping, dropmissing: bool = True
+    dictin1: Mapping, dictin2: Mapping, dropmissing: bool = True
 ) -> Dict:
     """Create a new dictionary from two dictionaries by averaging values
 
     Args:
-        dictin1 (MutableMapping): First input dictionary
-        dictin2 (MutableMapping): Second input dictionary
+        dictin1 (Mapping): First input dictionary
+        dictin2 (Mapping): Second input dictionary
         dropmissing (bool): Whether to drop keys missing in one dictionary. Defaults to True.
 
     Returns:
@@ -385,67 +382,109 @@ def avg_dicts(
 
 def read_list_from_csv(
     url: str,
-    headers: Union[int, List[int], List[str], None] = None,
+    headers: Union[int, ListTuple[int], ListTuple[str], None] = None,
     dict_form: bool = False,
     **kwargs: Any,
-) -> List[Union[Dict, List]]:
-    """Read a list of rows in dict or list form from a csv. The headers argument is either a row
-       number or list of row numbers (in case of multi-line headers) to be considered as headers
-       (rows start counting at 1), or the actual headers defined a list of strings. If not set,
-       all rows will be treated as containing values.
+) -> List[ListDict]:
+    """Read a list of rows in dict or list form from a csv. The headers argument is
+    either a row number or list of row numbers (in case of multi-line headers) to be
+    considered as headers (rows start counting at 1), or the actual headers defined as
+    a list of strings. If not set, all rows will be treated as containing values.
 
     Args:
         url (str): URL or path to read from
-        headers (Union[int, List[int], List[str], None]): Row number of headers. Defaults to None.
+        headers (Union[int, ListTuple[int], ListTuple[str], None]): Row number of headers. Defaults to None.
         dict_form (bool): Return dict (requires headers parameter) or list for each row. Defaults to False (list)
         **kwargs: Other arguments to pass to Tabulator Stream
 
     Returns:
-        List[Union[Dict, List]]: List of rows in dict or list form
+        List[ListDict]: List of rows in dict or list form
 
     """
     if dict_form and headers is None:
         raise ValueError("If dict_form is True, headers must not be None!")
-    stream = Stream(url, headers=headers, **kwargs)
-    stream.open()
-    result = stream.read(keyed=dict_form)
-    stream.close()
+    resource = get_frictionless_resource(url, headers=headers, **kwargs)
+    result = list()
+    if not dict_form:
+        result.append(resource.header)
+    for inrow in resource.row_stream:
+        if dict_form:
+            row = inrow.to_dict()
+        else:
+            row = inrow.to_list()
+        result.append(row)
+    resource.close()
     return result
 
 
 def write_list_to_csv(
     filepath: str,
-    list_of_rows: List[Union[MutableMapping, List]],
-    headers: Union[int, List[int], List[str], None] = None,
+    rows: List[ListDict],
+    headers: Union[int, ListTuple[str], None] = None,
+    columns: Union[ListTuple[int], ListTuple[str], None] = None,
 ) -> None:
-    """Write a list of rows in dict or list form to a csv. (The headers argument is either a row
-       number or list of row numbers (in case of multi-line headers) to be considered as headers
-       (rows start counting at 1), or the actual headers defined a list of strings. If not set,
-       all rows will be treated as containing values.)
+    """Write a list of rows in dict or list form to a csv. (The headers argument is
+    either a row number (rows start counting at 1), or the actual headers defined as a
+    list of strings. If not set, all rows will be treated as containing values.)
 
     Args:
         filepath (str): Path to write to
-        list_of_rows (List[Union[MutableMapping, List]]): List of rows in dict or list form
-        headers (Union[int, List[int], List[str], None]): Headers to write. Defaults to None.
+        rows (List[ListDict]): List of rows in dict or list form
+        headers (Union[int, ListTuple[str], None]): Headers to write. Defaults to None.
+        columns (Union[ListTuple[int], ListTuple[str], None]): Columns to write. Defaults to all.
 
     Returns:
         None
 
     """
-    stream = Stream(list_of_rows, headers=headers)
-    stream.open()
-    stream.save(filepath, format="csv")
-    stream.close()
+    if len(rows) != 0:
+        row = rows[0]
+        if isinstance(row, dict):
+            has_header = True
+            if columns:
+                newrows = list()
+                for row in rows:
+                    newrow = dict()
+                    for column in columns:
+                        newrow[column] = row[column]
+                    newrows.append(newrow)
+                rows = newrows
+                if headers is None:
+                    headers = columns
+        else:
+            if headers is None:
+                headers = 1
+            if isinstance(headers, int):
+                rowno = headers
+                headers = rows[rowno - 1]
+                rows = rows[rowno:]
+            has_header = False
+            if columns:
+                newrows = list()
+                for row in rows:
+                    newrow = list()
+                    for column in columns:
+                        newrow.append(row[column - 1])
+                    newrows.append(newrow)
+                rows = newrows
+        resource = get_frictionless_resource(
+            data=rows,
+            infer_types=True,
+            has_header=has_header,
+            headers=headers,
+        )
+        resource.write(filepath, format="csv")
+        resource.close()
 
 
-def args_to_dict(args: str) -> MutableMapping:
+def args_to_dict(args: str) -> Dict:
     """Convert command line arguments in a comma separated string to a dictionary
 
     Args:
         args (str): Command line arguments
 
     Returns:
-        MutableMapping: Dictionary of arguments
+        Dict: Dictionary of arguments
 
     """
     arguments = dict()
