@@ -11,9 +11,9 @@ from tempfile import gettempdir
 from typing import Any, Dict, Iterable, List, Optional, Tuple
 from urllib.parse import urlsplit
 
-from hdx.utilities import get_uuid
-from hdx.utilities.loader import load_file_to_str
-from hdx.utilities.saver import save_str_to_file
+from hdx.utilities.loader import load_text
+from hdx.utilities.saver import save_text
+from hdx.utilities.uuid import get_uuid
 
 logger = logging.getLogger(__name__)
 
@@ -107,7 +107,9 @@ def temp_dir(
     Returns:
         str: A temporary directory
     """
-    tempdir = get_temp_dir(folder, delete_if_exists=delete_if_exists, tempdir=tempdir)
+    tempdir = get_temp_dir(
+        folder, delete_if_exists=delete_if_exists, tempdir=tempdir
+    )
     try:
         yield tempdir
         if folder and delete_on_success:
@@ -131,13 +133,13 @@ def read_or_create_batch(folder: str, batch: Optional[str] = None) -> str:
     """
     batch_file = join(folder, "batch.txt")
     if exists(batch_file):
-        batch = load_file_to_str(batch_file, strip=True)
+        batch = load_text(batch_file, strip=True)
         logger.info(f"File BATCH = {batch}")
     else:
         if not batch:
             batch = get_uuid()
             logger.info(f"Generated BATCH = {batch}")
-        save_str_to_file(batch, batch_file)
+        save_text(batch, batch_file)
     return batch
 
 
@@ -166,9 +168,16 @@ def temp_dir_batch(
         Dict: Dictionary containing temporary directory in key folder and batch id in key batch
     """
     with temp_dir(
-        folder, delete_if_exists, delete_on_success, delete_on_failure, tempdir=tempdir
+        folder,
+        delete_if_exists,
+        delete_on_success,
+        delete_on_failure,
+        tempdir=tempdir,
     ) as tempdir:
-        yield {"folder": tempdir, "batch": read_or_create_batch(tempdir, batch)}
+        yield {
+            "folder": tempdir,
+            "batch": read_or_create_batch(tempdir, batch),
+        }
 
 
 def get_wheretostart(text: str, message: str, key: str) -> Optional[str]:
@@ -194,7 +203,10 @@ def get_wheretostart(text: str, message: str, key: str) -> Optional[str]:
 
 
 def progress_storing_folder(
-    info: Dict, iterator: Iterable[Dict], key: str, wheretostart: Optional[str] = None
+    info: Dict,
+    iterator: Iterable[Dict],
+    key: str,
+    wheretostart: Optional[str] = None,
 ) -> Tuple[Dict, Dict]:
     """Store progress in folder in key folder of info dictionary parameter. Yields 2 dictionaries. The first is the
     info dictionary. It contains in key folder the folder being used to store progress and in key progress the current
@@ -217,10 +229,12 @@ def progress_storing_folder(
     if not wheretostart:
         contents = getenv("WHERETOSTART")
         if contents:
-            wheretostart = get_wheretostart(contents, "Environment variable", key)
+            wheretostart = get_wheretostart(
+                contents, "Environment variable", key
+            )
         else:
             if exists(progress_file):
-                contents = load_file_to_str(progress_file, strip=True)
+                contents = load_text(progress_file, strip=True)
                 wheretostart = get_wheretostart(contents, "File", key)
             else:
                 wheretostart = None
@@ -233,7 +247,9 @@ def progress_storing_folder(
             if not found:
                 if current == wheretostart:
                     found = True
-                    logger.info(f"Starting run from WHERETOSTART {wheretostart}")
+                    logger.info(
+                        f"Starting run from WHERETOSTART {wheretostart}"
+                    )
                 else:
                     logger.info(
                         "Run not started. Ignoring {}. WHERETOSTART ({}) not matched.".format(
@@ -243,7 +259,7 @@ def progress_storing_folder(
                     continue
         output = f"{key}={current}"
         info["progress"] = output
-        save_str_to_file(output, progress_file)
+        save_text(output, progress_file)
         yield info, nextdict
     if wheretostart and not found:
         raise NotFoundError(
@@ -273,7 +289,9 @@ def wheretostart_tempdir_batch(
     if wheretostart:
         if wheretostart.upper() == "RESET":
             delete_if_exists = True
-            logger.info("Removing progress file and will start from beginning!")
+            logger.info(
+                "Removing progress file and will start from beginning!"
+            )
     with temp_dir_batch(
         folder,
         delete_if_exists,
@@ -310,7 +328,9 @@ def progress_storing_tempdir(
     Returns:
         Tuple[Dict,Dict]: A tuple of the form (info dictionary, next object in iterator)
     """
-    with wheretostart_tempdir_batch(folder, batch=batch, tempdir=tempdir) as info:
+    with wheretostart_tempdir_batch(
+        folder, batch=batch, tempdir=tempdir
+    ) as info:
         yield from progress_storing_folder(info, iterator, key)
 
 
@@ -343,7 +363,9 @@ def multiple_progress_storing_tempdir(
     if wheretostartenv:
         if wheretostartenv.upper() == "RESET":
             delete_if_exists = True
-            logger.info("Removing progress file and will start from beginning!")
+            logger.info(
+                "Removing progress file and will start from beginning!"
+            )
     with temp_dir_batch(
         folder,
         delete_if_exists,
@@ -361,7 +383,7 @@ def multiple_progress_storing_tempdir(
                 )
             else:
                 if exists(progress_file):
-                    contents = load_file_to_str(progress_file, strip=True)
+                    contents = load_text(progress_file, strip=True)
                     wheretostart = get_wheretostart(contents, "File", key)
                 else:
                     wheretostart = None
@@ -376,7 +398,7 @@ def multiple_progress_storing_tempdir(
                 for info, nextdict in progress_storing_folder(
                     info, iterators[i], key, wheretostart
                 ):
-                    save_str_to_file(info["progress"], progress_file)
+                    save_text(info["progress"], progress_file)
                     yield i, info, nextdict
                 if exists(progress_file):
                     remove(progress_file)
